#
# spec file for package imap
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

%define pkg_name imap
Name:           imap-openssl_1_1
Version:        2007e_suse
Release:        lp156.1.1
Summary:        IMAP4, POP2, and POP3 Mail Server
License:        Apache-2.0
Group:          Productivity/Networking/Email/Servers
Url:            http://www.washington.edu/imap/
Source0:        %{pkg_name}-2007e.tar.bz2
Source1:        README.SUSE
# pam config
Source2:        %{pkg_name}.pamd
Source3:        pop.pamd
# xinetd config
Source4:        %{pkg_name}.xinetd
# c-client config
Source5:        c-client.cf
Source6:        %{pkg_name}.firewall
Source100:      %{pkg_name}.rpmlintrc
Patch0:         %{pkg_name}-2001a-include.diff
Patch1:         %{pkg_name}-2004a-doc.diff
Patch2:         %{pkg_name}-2002e-ssl.diff
Patch3:         %{pkg_name}-2004-cflags.diff
Patch4:         %{pkg_name}-2001a-overflow.diff
Patch5:         %{pkg_name}-2007e-c++.patch
Patch6:         %{pkg_name}-2007e.patch
Patch7:         imap-openssl.patch
Patch8:         imap-implicit-decls.patch
Patch9:         imap-2007e-poll.patch
Patch10:        imap-2007f-format-security.patch
Patch11:        imap-openssl-1.1.patch
BuildRequires:  libopenssl-1_1-devel
BuildRequires:  pam-devel
Requires:       inet-daemon
Requires:       pam
BuildRequires:  fdupes

%description
This package contains IMAP4, POP2, and POP3 mail servers.

After installation, activate the servers in the file %{_sysconfdir}/inetd.conf.

%package -n libc-client2007e_suse_openssl_1_1
Summary:        IMAP4rev1/c-client Development Environment
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++

%description -n libc-client2007e_suse_openssl_1_1
This package contains the libraries for IMAP client programs.

%package devel
Summary:        IMAP4rev1/c-client Development Environment
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
Provides:       libc-client-devel = %{version}
Provides:       libc-client-devel-openssl_1_1
Requires:       libc-client2007e_suse_openssl_1_1 = %{version}

%description devel
This package contains the libraries and header files for IMAP client
programs.

%prep
%setup -q -n %{pkg_name}-2007e
%patch0
%patch1
%patch2
%patch3
%patch4
%patch5 -p1
%patch6 -p1
%patch7 -p1
%patch8 -p1
%patch9 -p1
%patch10 -p1
%patch11 -p1

#K & R declarations of errno won't work anymore..
#it a no longer an integer but a macro that expands to a function  call
find -type f -name "*.[h,c]" -exec sed -i -e '/extern int errno;/d' {} +

%build
export CFLAGS="-Wno-pointer-sign -Wno-parentheses -Wno-unused-result -Wno-unused-variable -Wno-implicit-function-declaration -Wno-unused-function %{optflags} -DOPENSSL_NO_SSL_INTERN -DDISABLE_POP_PROXY=1 -fPIC -fno-strict-aliasing -fstack-protector"
make %{?_smp_mflags} lnp MYCFLAGS="$CFLAGS" SSLTYPE=nopwd IP=6
make %{?_smp_mflags} lnp c-client
gcc $CFLAGS -shared -Wl,-soname,libc-client.so.%{version} -o libc-client.so.%{version} c-client/*.o -lpam

%install
mkdir -p %{buildroot}%{_prefix}/{sbin,share/man/man8,share/doc/packages/imap}
mkdir -p %{buildroot}%{_sysconfdir}/pam.d
install -m 755 imapd/imapd ipopd/ipop2d ipopd/ipop3d mtest/mtest %{buildroot}%{_sbindir}/
install -m 644 %{SOURCE2} %{buildroot}%{_sysconfdir}/pam.d/%{pkg_name}
install -m 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/pam.d/pop
install -m 644 -D %{SOURCE4} %{buildroot}%{_sysconfdir}/xinetd.d/%{pkg_name}
install -m 644 %{SOURCE5} %{buildroot}%{_sysconfdir}/c-client.cf
install -m 644 src/imapd/imapd.8 %{buildroot}%{_mandir}/man8/imapd.8
install -m 644 src/ipopd/ipopd.8 %{buildroot}%{_mandir}/man8/ipopd.8
install -m 644 %{SOURCE1} %{buildroot}%{_docdir}/%{pkg_name}/
install -m 644 CONTENTS README docs/RELNOTES %{buildroot}%{_docdir}/%{pkg_name}/
install -m 644 docs/{FAQ,bugs,imaprc,md5,naming,drivers}.txt %{buildroot}%{_docdir}/%{pkg_name}/
mkdir -p %{buildroot}/%{_includedir}/%{pkg_name}
cp src/osdep/tops-20/*.h %{buildroot}/%{_includedir}/%{pkg_name}
cp src/osdep/unix/*.h %{buildroot}/%{_includedir}/%{pkg_name}
cp src/c-client/*.h %{buildroot}/%{_includedir}/%{pkg_name}
cp c-client/linkage.{h,c} %{buildroot}/%{_includedir}/%{pkg_name}
cp c-client/osdep.h %{buildroot}/%{_includedir}/%{pkg_name}
mkdir -p %{buildroot}/%{_libdir}
install -m 644 c-client/c-client.a %{buildroot}/%{_libdir}/libc-client.a
ln -sf libc-client.a %{buildroot}/%{_libdir}/c-client.a
install -m 755 libc-client.so.%{version} %{buildroot}/%{_libdir}/
ln -sf libc-client.so.%{version} %{buildroot}/%{_libdir}/libc-client.so
ln -sf ..%{_sbindir}/imapd %{buildroot}%{_sysconfdir}/rimapd
ln -sf ..%{_sbindir}/ipop3d %{buildroot}%{_sysconfdir}/rpop3d
ln -sf ..%{_sbindir}/ipop2d %{buildroot}%{_sysconfdir}/rpop2d
install -d %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/
install -m 644 %{SOURCE6} %{buildroot}%{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{pkg_name}
mkdir -p %{buildroot}/%{_sysconfdir}/%{pkg_name}/certs
%fdupes %{buildroot}%{_includedir}

%post -n libc-client2007e_suse_openssl_1_1 -p /sbin/ldconfig
%postun -n libc-client2007e_suse_openssl_1_1 -p /sbin/ldconfig

%files
%{_sbindir}/*
%{_mandir}/man8/*
%config %{_sysconfdir}/pam.d/*
%dir %{_sysconfdir}/xinetd.d
%config(noreplace) %{_sysconfdir}/xinetd.d/%{pkg_name}
%{_sysconfdir}/%{pkg_name}
%{_sysconfdir}/rimapd
%{_sysconfdir}/rpop3d
%{_sysconfdir}/rpop2d
%doc %{_docdir}/%{pkg_name}

%files -n libc-client2007e_suse_openssl_1_1
%config(noreplace) %{_sysconfdir}/c-client.cf
%{_libdir}/*.so
%{_libdir}/*.so.*
%config %{_sysconfdir}/sysconfig/SuSEfirewall2.d/services/%{pkg_name}

%files devel
%{_libdir}/*.a
%{_includedir}/%{pkg_name}

%changelog
* Tue Sep  3 2024 Angelo Grossini <angelo@intercom.it>
- build with openssl deprecations
- remove useless declatation
